<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00004000PeriodoVigenciaContratoService;

class Sm00004000PeriodoVigenciaContratoController extends SMCrud {
    protected $dataSourceName = 'fct_prorrogcontrato_widget';
    protected $PeriodoVigenciaContratoService;
    
    public function __construct ($crudService, $environment, Sm00004000PeriodoVigenciaContratoService $PeriodoVigenciaContratoService) {
        parent::__construct($crudService, $environment);
        $this->PeriodoVigenciaContratoService  = $PeriodoVigenciaContratoService;
    }
    
    /* --- Save --- */
    public function save(Request $request, Response $response) {
        
        $request->setParameter('dbname', $this->dataSourceName);
        parent::save($request, $response);
        $response->addDataset(new DataSet('columnsToReturn', $this->crudService->getColumnsToReturn()));
    }
    
     /* --- Find --- */
    public function find(Request\Filter $request, Response $response) {
    
        $request->setParameter('dbname', $this->dataSourceName);
        parent::find($request, $response);
    }
    
     /* --- Delete --- */
    public function delete(Request $request, Response $response) {
    
        $request->setParameter('dbname', $this->dataSourceName);
        parent::delete($request, $response);
    }
    
    /**
     * A função "alteraVigenciaContrato" altera os dados de vigência do contrato
     */
    
    public function alteraVigenciaContrato(Request\Row $request, Response $response) {
    
        $row = $request->getRow();
        

        $dtInicVigContr   = $row['DTINICVIGCONTR'];
        $dtFinVigContr    = $row['DTFINVIGCONTR'];
        $seqContrato      = $row['NRSEQCONTRATO'];
        
        
        $InsereDadosContr = $this->PeriodoVigenciaContratoService->alteraVigenciaContrato($dtInicVigContr, $dtFinVigContr, $seqContrato);
        
    }    
    
    
    public function alteraVigenciaContratoNovo(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrorg            = $row['NRORG'];
            $idutilizacomp    = $row['IDUTILIZACOMP'];
            $dtInicVigContr   = $row['DTINICVIGCONTR'];
            $dtFinVigContr    = $row['DTFINVIGCONTR'];
            $periodoextendido = $row['PERIODOEXTENDIDO'];
            $seqContrato      = $row['NRSEQCONTRATO'];
            
            $this->PeriodoVigenciaContratoService->alteraVigenciaContratoNovo($nrorg, $idutilizacomp, $dtInicVigContr, $dtFinVigContr, $periodoextendido, $seqContrato);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }    
    
    /**
     * A função "validaDadosProrrog" valida se ja existem alterações de vigência para o contrato
     */
    
    public function validaDadosProrrog(Request\Row $request, Response $response) {
    
        $row = $request->getRow();
        
        $seqContrato = $row['NRSEQCONTRATO'];
        
        $ValidaDadosProrrog = $this->PeriodoVigenciaContratoService->validaDadosProrrog($seqContrato);
        
        $dtsValDadosProrrog = new DataSet('NRSEQPRORRCONT', array('SEQPRORRCONT'=>$ValidaDadosProrrog));
        
        $response->addDataSet($dtsValDadosProrrog);
        
    } 
    
    /**
     * A função "alteraDadosProrrog" inativa as alterações de vigência do contrato
     */
    
    public function alteraDadosProrrog(Request\Row $request, Response $response) {
    
        $row = $request->getRow();
        
        $seqContrato = $row['NRSEQCONTRATO'];
        $seqprorrog = $row['NRSEQPRORRCONT'];
        
        $AlteraDadosProrrog = $this->PeriodoVigenciaContratoService->alteraDadosProrrog($seqContrato, $seqprorrog);
        
    }     
}
?>