<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00006000ItemComposicaoServicosFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Retorna os itens da composição que já existem para os serviços informado.
     * 
     * @param string $servicos
     * @param integer $nrorg
     */
    public function getItensExistentes($nrcompservico, $servicos, $nrorg) {
        $sql = "SELECT NRITCOMPSERVICO, CDSERVORCA
                  FROM FCT_ITCOMPSERVICO
                 WHERE NRCOMPSERVICO = :NRCOMPSERVICO
                   AND NRORG         = :NRORG
                   AND CDSERVORCA    IN (".$servicos.")";
        
        $params = array(
            "NRCOMPSERVICO" => $nrcompservico,
            "NRORG"         => $nrorg
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Exclui o serviço da composição junto com seus filhos.
     * 
     * @param mixed[] @params
     */
    public function excluirItemComposicaoEmCascata(array $params) {
        $sql = "DELETE FROM FCT_ITCOMPSERVICO
                 WHERE NRITCOMPSERVICO IN (
                      SELECT NRITCOMPSERVICO FROM (
                             SELECT *
                               FROM FCT_ITCOMPSERVICO
                              WHERE NRORG         = :NRORG
                                AND NRCOMPSERVICO = :NRCOMPSERVICO
                          )
                        CONNECT BY PRIOR IDELEMENTO = IDELEMENTOPAI
                          START WITH IDELEMENTO     = :IDELEMENTO
                   )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Valida se o Elemento informado já existe na tabela de Itens da Composição.
     * 
     * @param mixed[] $params
     */
    public function verificarSeElementoExiste(array $params) {
        $sql = "SELECT COUNT(*) AS EXISTE
                  FROM FCT_ITCOMPSERVICO
                 WHERE NRCOMPSERVICO = :NRCOMPSERVICO
                   AND IDELEMENTO    = :IDELEMENTO
                   AND NRORG         = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Replica a obrigatoriedade do item da composição para seus itens filhos.
     * 
     * @param mixed[] $params
     */
    public function replicarObrigatoriedadeItensFilhos(array $params) {
        $sql = "UPDATE FCT_ITCOMPSERVICO
                   SET IDSERVOBRIGCOMP = :IDSERVOBRIGCOMP,
                       DTULTATU        = SYSDATE,
                       CDOPERULTATU    = :CDOPERULTATU,
                       NRORGULTATU     = :NRORGULTATU
                 WHERE NRCOMPSERVICO   = :NRCOMPSERVICO
                   AND NRORG           = :NRORG
                   AND IDELEMENTO     IN (SELECT IDELEMENTO
                                            FROM FCT_ITCOMPSERVICO
                                           WHERE IDELEMENTO         <> :IDELEMENTO
                                             AND NRORG               = :NRORG
                                             AND NRCOMPSERVICO       = :NRCOMPSERVICO
                                           START WITH IDELEMENTO     = :IDELEMENTO
                                         CONNECT BY PRIOR IDELEMENTO = IDELEMENTOPAI)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}

?>